@@ -5,8 +5,7 @@
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
-from .base import AuthorizationRule
-from .base import RuleNotForModelClasses
+from .base import AuthorizationRule, RuleNotForModelClasses
 
 
 class AttributeAccessRule(AuthorizationRule):
