@@ -7,15 +7,19 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 from anyblok import reload_module_if_blok_is_reloading
+
 from . import base
+
 reload_module_if_blok_is_reloading(base)
 from . import sqlbase
+
 reload_module_if_blok_is_reloading(sqlbase)
 from . import sqlviewbase
+
 reload_module_if_blok_is_reloading(sqlviewbase)
-from . import session
-reload_module_if_blok_is_reloading(session)
 from . import query
+
 reload_module_if_blok_is_reloading(query)
 from . import instrumentedlist
+
 reload_module_if_blok_is_reloading(instrumentedlist)
