@@ -6,10 +6,11 @@
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
+from logging import getLogger
+
+from anyblok.column import Boolean, String
 from anyblok.declarations import Declarations, listen
 from anyblok.field import Function
-from anyblok.column import String, Boolean
-from logging import getLogger
 
 logger = getLogger(__name__)
 
@@ -31,38 +32,38 @@ class Model:
     table = String(size=256)
     schema = String()
     is_sql_model = Boolean(label="Is a SQL model")
-    description = Function(fget='get_model_doc_string')
+    description = Function(fget="get_model_doc_string")
 
     def get_model_doc_string(self):
-        """ Return the docstring of the model
-        """
+        """Return the docstring of the model"""
         m = self.anyblok.get(self.name)
-        if hasattr(m, '__doc__'):
-            return m.__doc__ or ''
+        if hasattr(m, "__doc__"):
+            return m.__doc__ or ""
 
-        return ''  # pragma: no cover
+        return ""  # pragma: no cover
 
-    @listen('Model.System.Model', 'Update Model')
+    @listen("Model.System.Model", "Update Model")
     def listener_update_model(cls, model):
-        cls.anyblok.System.Cache.invalidate(model, '_fields_description')
-        cls.anyblok.System.Cache.invalidate(model, 'getFieldType')
-        cls.anyblok.System.Cache.invalidate(model, 'get_primary_keys')
+        cls.anyblok.System.Cache.invalidate(model, "_fields_description")
+        cls.anyblok.System.Cache.invalidate(model, "getFieldType")
+        cls.anyblok.System.Cache.invalidate(model, "get_primary_keys")
         cls.anyblok.System.Cache.invalidate(
-            model, 'find_remote_attribute_to_expire')
+            model, "find_remote_attribute_to_expire"
+        )
+        cls.anyblok.System.Cache.invalidate(model, "find_relationship")
         cls.anyblok.System.Cache.invalidate(
-            model, 'find_relationship')
-        cls.anyblok.System.Cache.invalidate(
-            model, 'get_hybrid_property_columns')
+            model, "get_hybrid_property_columns"
+        )
 
     @classmethod
     def get_field_model(cls, field):
         ftype = field.property.__class__.__name__
-        if ftype == 'ColumnProperty':
+        if ftype == "ColumnProperty":
             return cls.anyblok.System.Column
-        elif ftype == 'RelationshipProperty':
+        elif ftype in ("Relationship", "RelationshipProperty"):
             return cls.anyblok.System.RelationShip
         else:
-            raise Exception('Not implemented yet')  # pragma: no cover
+            raise Exception("Not implemented yet")  # pragma: no cover
 
     @classmethod
     def get_field(cls, model, cname):
@@ -84,8 +85,8 @@ class Model:
         query = Field.query()
         query = query.filter(Field.model == model)
         query = query.filter(Field.name.notin_(m.loaded_columns))
-        for model_ in query.all():
-            if model_.entity_type == 'Model.System.RelationShip':
+        for model_ in query:
+            if model_.entity_type == "Model.System.RelationShip":
                 if model_.remote:
                     continue
                 else:  # pragma: no cover
@@ -115,8 +116,12 @@ class Model:
         fsp = cls.anyblok.loaded_namespaces_first_step
         m = cls.anyblok.get(model)
         is_sql_model = len(m.loaded_columns) > 0
-        cls.insert(name=model, table=table, schema=m.__db_schema__,
-                   is_sql_model=is_sql_model)
+        cls.insert(
+            name=model,
+            table=table,
+            schema=m.__db_schema__,
+            is_sql_model=is_sql_model,
+        )
         for cname in m.loaded_columns:
             field, Field = cls.get_field(m, cname)
             cname = Field.get_cname(field, cname)
@@ -125,7 +130,7 @@ class Model:
 
     @classmethod
     def update_list(cls):
-        """ Insert and update the table of models
+        """Insert and update the table of models
 
         :exception: Exception
         """
@@ -134,18 +139,18 @@ class Model:
                 # TODO need refactor, then try except pass whenever refactor
                 # not apply
                 m = cls.anyblok.get(model)
-                table = ''
-                if hasattr(m, '__tablename__'):
+                table = ""
+                if hasattr(m, "__tablename__"):
                     table = m.__tablename__
 
-                _m = cls.query('name').filter(cls.name == model)
+                _m = cls.query("name").filter(cls.name == model)
                 if _m.count():
                     cls.update_fields(model, table)
                 else:
                     cls.add_fields(model, table)
 
                 if m.loaded_columns:
-                    cls.fire('Update Model', model)
+                    cls.fire("Update Model", model)
 
             except Exception as e:
                 logger.exception(str(e))
@@ -153,11 +158,12 @@ class Model:
         # remove model and field which are not in loaded_namespaces
         query = cls.query()
         query = query.filter(
-            cls.name.notin_(cls.anyblok.loaded_namespaces.keys()))
+            cls.name.notin_(cls.anyblok.loaded_namespaces.keys())
+        )
         Field = cls.anyblok.System.Field
-        for model_ in query.all():
+        for model_ in query:
             Q = Field.query().filter(Field.model == model_.name)
-            for field in Q.all():
+            for field in Q:
                 field.delete()
 
             model_.delete()
