@@ -9,12 +9,12 @@
 import pytest
 
 
-@pytest.mark.usefixtures('rollback_registry')
+@pytest.mark.usefixtures("rollback_registry")
 class TestSystemBlok:
     def test_list_by_state_installed(self, rollback_registry):
         registry = rollback_registry
-        installed = registry.System.Blok.list_by_state('installed')
-        core_is_installed = 'anyblok-core' in installed
+        installed = registry.System.Blok.list_by_state("installed")
+        core_is_installed = "anyblok-core" in installed
         assert core_is_installed is True
 
     def test_list_by_state_without_state(self, rollback_registry):
@@ -23,4 +23,4 @@ class TestSystemBlok:
 
     def test_is_installed(self, rollback_registry):
         registry = rollback_registry
-        assert registry.System.Blok.is_installed('anyblok-core') is True
+        assert registry.System.Blok.is_installed("anyblok-core") is True
