@@ -5,16 +5,16 @@
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
-from .mapper import MapperAdapter
 from .common import add_autodocs
+from .mapper import MapperAdapter
 
 
 class DeclarationsException(AttributeError):
-    """ Simple Exception for Declarations """
+    """Simple Exception for Declarations"""
 
 
 class Declarations:
-    """ Represents all the declarations done by the bloks
+    """Represents all the declarations done by the bloks
 
     .. warning::
         This is a global information, during the execution you must use the
@@ -26,11 +26,12 @@ class Declarations:
         from anyblok import Declarations
 
     """
+
     declaration_types = {}
 
     @classmethod
     def register(cls, parent, cls_=None, **kwargs):
-        """ Method to add the blok in the registry under a type of declaration
+        """Method to add the blok in the registry under a type of declaration
 
         :param parent: An existing blok class in the Declaration
         :param ``cls_``: The ``class`` object to add in the Declaration
@@ -39,23 +40,26 @@ class Declarations:
         """
 
         def wrapper(self):
-            name = kwargs.get('name_', self.__name__)
+            name = kwargs.get("name_", self.__name__)
             if parent.__declaration_type__ not in cls.declaration_types:
                 raise DeclarationsException(
-                    "No parents %r for %s" % (parent, name))  # pragma: no cover
+                    "No parents %r for %s" % (parent, name)
+                )  # pragma: no cover
 
             declaration = cls.declaration_types[parent.__declaration_type__]
             declaration.register(parent, name, self, **kwargs)
 
             node = getattr(parent, name)
-            setattr(node, '__declaration_type__', parent.__declaration_type__)
-            setattr(node, '__registry_name__',
-                    parent.__registry_name__ + '.' + name)
+            setattr(node, "__declaration_type__", parent.__declaration_type__)
+            setattr(
+                node, "__registry_name__", parent.__registry_name__ + "." + name
+            )
 
             # Only for auto doc with autoanyblok-declaration directive
-            setattr(self, '__declaration__', declaration)
-            setattr(self, '__registry_name__',
-                    parent.__registry_name__ + '.' + name)
+            setattr(self, "__declaration__", declaration)
+            setattr(
+                self, "__registry_name__", parent.__registry_name__ + "." + name
+            )
             return self
 
         if cls_:
@@ -65,7 +69,7 @@ class Declarations:
 
     @classmethod
     def unregister(cls, entry, cls_):
-        """ Method to remove the blok from a type of declaration
+        """Method to remove the blok from a type of declaration
 
         :param entry: declaration entry of the model where the ``cls_``
             must be removed
@@ -79,10 +83,16 @@ class Declarations:
         return cls_
 
     @classmethod
-    def add_declaration_type(cls, cls_=None, isAnEntry=False,
-                             pre_assemble=None, assemble=None,
-                             initialize=None, unload=None):
-        """ Add a declaration type
+    def add_declaration_type(
+        cls,
+        cls_=None,
+        isAnEntry=False,
+        pre_assemble=None,
+        assemble=None,
+        initialize=None,
+        unload=None,
+    ):
+        """Add a declaration type
 
         :param cls_: The ``class`` object to add as a world of the MetaData
         :param isAnEntry: if true the type will be assembled by the registry
@@ -95,15 +105,17 @@ class Declarations:
 
         def wrapper(self):
             from anyblok.registry import RegistryManager
+
             name = self.__name__
             if name in cls.declaration_types:
                 raise DeclarationsException(
-                    "The declaration type %r is already defined" % name)
+                    "The declaration type %r is already defined" % name
+                )
 
             cls.declaration_types[name] = self
 
-            setattr(self, '__registry_name__', name)
-            setattr(self, '__declaration_type__', name)
+            setattr(self, "__registry_name__", name)
+            setattr(self, "__declaration_type__", name)
             setattr(cls, name, self)
 
             if isAnEntry:
@@ -122,12 +134,14 @@ class Declarations:
                     name,
                     pre_assemble_callback=pre_assemble_callback,
                     assemble_callback=assemble_callback,
-                    initialize_callback=initialize_callback)
+                    initialize_callback=initialize_callback,
+                )
 
             # All declaration type can need to be unload declarated values
             if unload and hasattr(self, unload):
                 RegistryManager.declare_unload_callback(
-                    name, getattr(self, unload))  # pragma: no cover
+                    name, getattr(self, unload)
+                )  # pragma: no cover
 
             return self
 
@@ -140,7 +154,9 @@ class Declarations:
 def cache(size=128):
     autodoc = """
     **Cached method** with size=%(size)s
-    """ % dict(size=size)
+    """ % dict(
+        size=size
+    )
 
     def wrapper(method):
         add_autodocs(method, autodoc)
@@ -155,7 +171,9 @@ def cache(size=128):
 def classmethod_cache(size=128):
     autodoc = """
     **Cached classmethod** with size=%(size)s
-    """ % dict(size=size)
+    """ % dict(
+        size=size
+    )
 
     def wrapper(method):
         add_autodocs(method, autodoc)
@@ -190,7 +208,9 @@ def listen(*args, **kwargs):
     autodoc = """
     **listen** event call with the arguments %(args)r and the positionnal
     argument %(kwargs)r
-    """ % dict(args=args, kwargs=kwargs)
+    """ % dict(
+        args=args, kwargs=kwargs
+    )
 
     mapper = MapperAdapter(*args, **kwargs)
 
