@@ -5,9 +5,8 @@
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
-from anyblok.declarations import Declarations, cache
 from anyblok.column import Integer, String
-
+from anyblok.declarations import Declarations, cache
 
 register = Declarations.register
 Model = Declarations.Model
@@ -15,7 +14,6 @@ Model = Declarations.Model
 
 @register(Model)
 class Test:
-
     id = Integer(primary_key=True)
     blok = String()
     mode = String()
@@ -27,15 +25,14 @@ class Test:
 
 @register(Model.System)
 class Blok:
-
     def install(self):
         super(Blok, self).install()
-        self.anyblok.Test.insert(blok=self.name, mode='install')
+        self.anyblok.Test.insert(blok=self.name, mode="install")
 
     def upgrade(self):
         super(Blok, self).upgrade()
-        self.anyblok.Test.insert(blok=self.name, mode='update')
+        self.anyblok.Test.insert(blok=self.name, mode="update")
 
     def load(self):
         super(Blok, self).load()
-        self.anyblok.Test.insert(blok=self.name, mode='load')
+        self.anyblok.Test.insert(blok=self.name, mode="load")
