@@ -9,11 +9,9 @@ from anyblok.blok import Blok
 
 
 class TestBlok(Blok):
-    version = '1.0.0'
+    version = "1.0.0"
 
-    required = [
-        'test-blok7', 'model_authz'
-    ]
+    required = ["test-blok7", "model_authz"]
 
     @classmethod
     def import_declaration_module(cls):
@@ -22,4 +20,5 @@ class TestBlok(Blok):
     @classmethod
     def reload_declaration_module(cls, reload):
         from . import declarations
+
         reload(declarations)
