@@ -9,6 +9,5 @@ from anyblok.blok import Blok
 
 
 class TestBlok(Blok):
-
-    version = '1.0.0'
-    conflicting = ['test-blok1']
+    version = "1.0.0"
+    conflicting = ["test-blok1"]
