@@ -11,8 +11,8 @@ from anyblok.blok import Blok
 class TestBlok(Blok):
     """Test blok15"""
 
-    version = '1.0.0'
+    version = "1.0.0"
 
     required = [
-        'test-undefined',
+        "test-undefined",
     ]
