@@ -9,9 +9,8 @@ from anyblok.blok import Blok
 
 
 class TestBlok(Blok):
-
-    version = '1.0.0'
+    version = "1.0.0"
 
     required = [
-        'test-blok2',
+        "test-blok2",
     ]
