@@ -9,10 +9,9 @@ from anyblok.blok import Blok
 
 
 class TestBlok(Blok):
-
-    version = '1.0.0'
+    version = "1.0.0"
 
     conditional = [
-        'test-blok1',
-        'test-blok4',
+        "test-blok1",
+        "test-blok4",
     ]
