@@ -7,6 +7,7 @@
 # obtain one at http://mozilla.org/MPL/2.0/.
 from anyblok import Declarations
 from anyblok.column import Integer
+
 from ..authorization import TestRuleOne, TestRuleTwo
 
 register = Declarations.register
@@ -15,15 +16,13 @@ Model = Declarations.Model
 
 @register(Model)
 class Test:
-
-    test2 = Integer(foreign_key=Model.Test2.use('id'))
+    test2 = Integer(foreign_key=Model.Test2.use("id"))
 
 
-Declarations.AuthorizationBinding(Declarations.Model.Test,
-                                  TestRuleOne(),
-                                  permission='Other')
-Declarations.AuthorizationBinding(Declarations.Model.Test,
-                                  TestRuleOne())
-Declarations.AuthorizationBinding(Declarations.Model.Test,
-                                  TestRuleTwo(),
-                                  permission='Write')
+Declarations.AuthorizationBinding(
+    Declarations.Model.Test, TestRuleOne(), permission="Other"
+)
+Declarations.AuthorizationBinding(Declarations.Model.Test, TestRuleOne())
+Declarations.AuthorizationBinding(
+    Declarations.Model.Test, TestRuleTwo(), permission="Write"
+)
