@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
-foo = 'bar'
+foo = "bar"
 
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
