@@ -6,10 +6,11 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 import pytest
-from anyblok.registry import RegistryManager
+
 from anyblok import Declarations
-from anyblok.environment import EnvironmentManager
 from anyblok.blok import BlokManager
+from anyblok.environment import EnvironmentManager
+from anyblok.registry import RegistryManager
 
 register = Declarations.register
 unregister = Declarations.unregister
@@ -27,56 +28,53 @@ def bloks_loaded(request):
 
 
 class TestCoreInterfaceCoreBase:
-
-    _corename = 'Base'
+    _corename = "Base"
 
     @pytest.fixture(autouse=True, scope="class")
     def add_testCore(self, request, bloks_loaded):
         def reset():
-            EnvironmentManager.set('current_blok', None)
-            del RegistryManager.loaded_bloks['testCore' + self._corename]
+            EnvironmentManager.set("current_blok", None)
+            del RegistryManager.loaded_bloks["testCore" + self._corename]
 
         request.addfinalizer(reset)
-        RegistryManager.init_blok('testCore' + self._corename)
-        EnvironmentManager.set('current_blok', 'testCore' + self._corename)
+        RegistryManager.init_blok("testCore" + self._corename)
+        EnvironmentManager.set("current_blok", "testCore" + self._corename)
 
     @pytest.fixture(autouse=True)
     def initialize_testCore(self, bloks_loaded):
-        blokname = 'testCore' + self._corename
-        RegistryManager.loaded_bloks[blokname]['Core'][self._corename] = []
+        blokname = "testCore" + self._corename
+        RegistryManager.loaded_bloks[blokname]["Core"][self._corename] = []
 
     def assertInCore(self, *args):
-        blokname = 'testCore' + self._corename
+        blokname = "testCore" + self._corename
         blok = RegistryManager.loaded_bloks[blokname]
-        assert len(blok['Core'][self._corename]) == len(args)
+        assert len(blok["Core"][self._corename]) == len(args)
         for cls_ in args:
-            hasCls = cls_ in blok['Core'][self._corename]
+            hasCls = cls_ in blok["Core"][self._corename]
             assert hasCls is True
 
     def assertInRemoved(self, cls):
-        core = RegistryManager.loaded_bloks['testCoreBase']['removed']
+        core = RegistryManager.loaded_bloks["testCoreBase"]["removed"]
         if cls in core:
             return True
 
-        self.fail('Not in removed')
+        self.fail("Not in removed")
 
     def test_add_interface(self):
-        register(Core, cls_=OneInterface, name_='Base')
-        assert 'Core' == Core.Base.__declaration_type__
+        register(Core, cls_=OneInterface, name_="Base")
+        assert "Core" == Core.Base.__declaration_type__
         self.assertInCore(OneInterface)
         dir(Declarations.Core.Base)
 
     def test_add_interface_with_decorator(self):
-
         @register(Core)
         class Base:
             pass
 
-        assert 'Core' == Core.Base.__declaration_type__
+        assert "Core" == Core.Base.__declaration_type__
         self.assertInCore(Base)
 
     def test_add_two_interface(self):
-
         register(Core, cls_=OneInterface, name_="Base")
 
         @register(Core)
@@ -86,7 +84,6 @@ class TestCoreInterfaceCoreBase:
         self.assertInCore(OneInterface, Base)
 
     def test_remove_interface_with_1_cls_in_registry(self):
-
         register(Core, cls_=OneInterface, name_="Base")
         self.assertInCore(OneInterface)
         unregister(Core.Base, OneInterface)
@@ -94,7 +91,6 @@ class TestCoreInterfaceCoreBase:
         self.assertInRemoved(OneInterface)
 
     def test_remove_interface_with_2_cls_in_registry(self):
-
         register(Core, cls_=OneInterface, name_="Base")
 
         @register(Core)
