@@ -7,7 +7,9 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 import pytest  # noqa
+
 from anyblok.blok import BlokManager
+
 from .conftest import init_registry
 
 
@@ -18,12 +20,10 @@ def bloks_loaded(request, configuration_loaded):
 
 
 class TestCoreQuery:
-
     @pytest.fixture(autouse=True)
     def close_registry(self, request, bloks_loaded):
-
         def close():
-            if hasattr(self, 'registry'):
+            if hasattr(self, "registry"):
                 self.registry.close()
 
         request.addfinalizer(close)
@@ -33,15 +33,13 @@ class TestCoreQuery:
         return self.registry
 
     def test_inherit(self):
-
         def inherit():
-
             from anyblok import Declarations
+
             Core = Declarations.Core
 
             @Declarations.register(Core)
             class Query:
-
                 def foo(self):
                     return True
 
