@@ -6,12 +6,12 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 import pytest
+
 from anyblok import Declarations
 from anyblok.declarations import DeclarationsException
 
 
 class OneType:
-
     @classmethod
     def register(cls, parent, name, cls_, **kwargs):
         setattr(parent, name, cls_)
@@ -22,12 +22,10 @@ class OneType:
 
 
 class TestDeclaration:
-
     @pytest.fixture(autouse=True)
     def tearDown(self, request):
-
         def reset():
-            for type_ in ['OneType', 'MyOneType']:
+            for type_ in ["OneType", "MyOneType"]:
                 if type_ in Declarations.declaration_types:
                     del Declarations.declaration_types[type_]
 
@@ -35,7 +33,7 @@ class TestDeclaration:
 
     def test_add(self):
         Declarations.add_declaration_type(cls_=OneType)
-        assert Declarations.declaration_types['OneType'] == OneType
+        assert Declarations.declaration_types["OneType"] == OneType
 
         class SubType:
             pass
@@ -47,17 +45,16 @@ class TestDeclaration:
         Declarations.add_declaration_type(cls_=OneType)
         try:
             Declarations.add_declaration_type(cls_=OneType)
-            self.fail('No watch dog for doublon declarations type')
+            self.fail("No watch dog for doublon declarations type")
         except DeclarationsException:
             pass
 
     def test_add_decoration(self):
-
         @Declarations.add_declaration_type()
         class MyOneType(OneType):
             pass
 
-        assert Declarations.declaration_types['MyOneType'] == MyOneType
+        assert Declarations.declaration_types["MyOneType"] == MyOneType
 
         @Declarations.register(Declarations.MyOneType)
         class SubType:
