@@ -6,13 +6,15 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 import pytest
-from anyblok.environment import (EnvironmentManager,
-                                 ThreadEnvironment,
-                                 EnvironmentException)
+
+from anyblok.environment import (
+    EnvironmentException,
+    EnvironmentManager,
+    ThreadEnvironment,
+)
 
 
 class MockEnvironment:
-
     values = {}
 
     @classmethod
@@ -29,10 +31,8 @@ class MockEnvironment:
 
 
 class TestEnvironment:
-
     @pytest.fixture(autouse=True)
     def wrapper(self, request):
-
         def reset():
             EnvironmentManager.define_environment_cls(ThreadEnvironment)
 
@@ -40,16 +40,16 @@ class TestEnvironment:
         EnvironmentManager.define_environment_cls(MockEnvironment)
 
     def test_set_and_get_variable(self):
-        db_name = 'test db name'
-        EnvironmentManager.set('db_name', db_name)
-        assert EnvironmentManager.get('db_name') == db_name
+        db_name = "test db name"
+        EnvironmentManager.set("db_name", db_name)
+        assert EnvironmentManager.get("db_name") == db_name
 
     def test_without_environment_for_set(self):
         # don't use define_environment_cls, because she must be verify
         EnvironmentManager.environment = None
         try:
-            EnvironmentManager.set('db_name', 'test')
-            self.fail('No watchdog for None environment')
+            EnvironmentManager.set("db_name", "test")
+            self.fail("No watchdog for None environment")
         except EnvironmentException:
             pass
 
@@ -57,8 +57,8 @@ class TestEnvironment:
         # don't use define_environment_cls, because she must be verify
         EnvironmentManager.environment = None
         try:
-            EnvironmentManager.get('db_name')
-            self.fail('No watchdog for None environment')
+            EnvironmentManager.get("db_name")
+            self.fail("No watchdog for None environment")
         except EnvironmentException:
             pass
 
@@ -75,9 +75,7 @@ class TestEnvironment:
             pass
 
     def test_bad_define_environment_scoped_function_session(self):
-
         class Env:
-
             @classmethod
             def setter(cls, key, value):
                 pass
@@ -89,22 +87,18 @@ class TestEnvironment:
         self.check_bad_define_environment(Env)
 
         class Env(MockEnvironment):
-
-            scoped_function_for_session = 'other'
+            scoped_function_for_session = "other"
 
         self.check_bad_define_environment(Env)
 
         class Env(MockEnvironment):
-
             def scoped_function_for_session(self):
                 pass
 
         self.check_bad_define_environment(Env)
 
     def test_bad_define_environment_setter(self):
-
         class Env:
-
             @classmethod
             def scoped_function_for_session(cls):
                 pass
@@ -116,22 +110,18 @@ class TestEnvironment:
         self.check_bad_define_environment(Env)
 
         class Env(MockEnvironment):
-
             setter = None
 
         self.check_bad_define_environment(Env)
 
         class Env(MockEnvironment):
-
             def setter(self, key, value):
                 pass
 
         self.check_bad_define_environment(Env)
 
     def test_bad_define_environment_getter(self):
-
         class Env:
-
             @classmethod
             def scoped_function_for_session(cls):
                 pass
@@ -143,13 +133,11 @@ class TestEnvironment:
         self.check_bad_define_environment(Env)
 
         class Env(MockEnvironment):
-
             getter = None
 
         self.check_bad_define_environment(Env)
 
         class Env(MockEnvironment):
-
             def getter(self, key, default):
                 pass
 
@@ -157,11 +145,10 @@ class TestEnvironment:
 
 
 class TestThreadEnvironment:
-
     def test_set_and_get_variable(self):
-        db_name = 'test db name'
-        EnvironmentManager.set('db_name', db_name)
-        assert EnvironmentManager.get('db_name') == db_name
+        db_name = "test db name"
+        EnvironmentManager.set("db_name", db_name)
+        assert EnvironmentManager.get("db_name") == db_name
 
     def test_scoped_function_session(self):
         assert EnvironmentManager.scoped_function_for_session() is None
