@@ -6,9 +6,11 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 import pytest
+
 from anyblok import Declarations
 from anyblok.column import Integer, String
 from anyblok.relationship import Many2One
+
 from .conftest import init_registry
 
 register = Declarations.register
@@ -18,7 +20,6 @@ Core = Declarations.Core
 
 
 def simple_subclass_model():
-
     @register(Model)
     class Test:
         id = Integer(primary_key=True)
@@ -30,16 +31,13 @@ def simple_subclass_model():
 
 
 def simple_subclass_Core_Base():
-
     @register(Core)
     class Base:
-
         def mymethod(self):
             return 1
 
     @register(Core)  # noqa
     class Base:
-
         def mymethod(self):
             return 10 * super(Base, self).mymethod()
 
@@ -49,16 +47,13 @@ def simple_subclass_Core_Base():
 
 
 def simple_subclass_Core_SqlBase():
-
     @register(Core)
     class SqlBase:
-
         def mymethod(self):
             return 1
 
     @register(Core)  # noqa
     class SqlBase:
-
         def mymethod(self):
             return 10 * super(SqlBase, self).mymethod()
 
@@ -68,7 +63,6 @@ def simple_subclass_Core_SqlBase():
 
 
 def simple_subclass_model_change_type():
-
     @register(Model)
     class Test:
         id = Integer(primary_key=True)
@@ -80,7 +74,6 @@ def simple_subclass_model_change_type():
 
 
 def simple_subclass_model_change_type_and_subclass_add_field():
-
     @register(Model)
     class Test:
         id = Integer(primary_key=True)
@@ -96,126 +89,99 @@ def simple_subclass_model_change_type_and_subclass_add_field():
 
 
 def mixin_one_model():
-
     @register(Mixin)
     class MixinName:
-
         name = String()
 
     @register(Model)
     class Test(Mixin.MixinName):
-
         id = Integer(primary_key=True)
         other = String()
 
 
 def mixin_two_model():
-
     @register(Mixin)
     class MixinName:
-
         name = String()
 
     @register(Model)
     class Test(Mixin.MixinName):
-
         id = Integer(primary_key=True)
         other = String()
 
     @register(Model)
     class Test2(Mixin.MixinName):
-
         id = Integer(primary_key=True)
         other = String()
 
 
 def mixin_one_model_with_subclass():
-
     @register(Mixin)
     class MixinName:
-
         name = String()
 
     @register(Model)
     class Test(Mixin.MixinName):
-
         id = Integer(primary_key=True)
 
     @register(Model)  # noqa
     class Test:
-
         other = String()
 
 
 def mixin_one_model_by_subclass():
-
     @register(Mixin)
     class MixinName:
-
         name = String()
 
     @register(Model)
     class Test:
-
         id = Integer(primary_key=True)
 
     @register(Model)  # noqa
     class Test(Mixin.MixinName):
-
         other = String()
 
 
 def mixin_with_foreign_key_one_model():
-
     @register(Model)
     class TestFk:
-
         name = String(primary_key=True)
 
     @register(Mixin)
     class MixinName:
-
-        name = String(foreign_key=Model.TestFk.use('name'))
+        name = String(foreign_key=Model.TestFk.use("name"))
 
     @register(Model)
     class Test(Mixin.MixinName):
-
         id = Integer(primary_key=True)
 
 
 def mixin_with_foreign_key_two_model():
-
     @register(Model)
     class TestFk:
-
         name = String(primary_key=True)
 
     @register(Mixin)
     class MixinName:
-
-        name = String(foreign_key=Model.TestFk.use('name'))
+        name = String(foreign_key=Model.TestFk.use("name"))
 
     @register(Model)
     class Test(Mixin.MixinName):
-
         id = Integer(primary_key=True)
 
     @register(Model)
     class Test2(Mixin.MixinName):
-
         id = Integer(primary_key=True)
 
 
 def mixin_one_model_by_subclass_and_with():
-
     @register(Mixin)
     class MixinName:
-
         name = String()
 
     @register(Model)
     class Test:
-
         id = Integer(primary_key=True)
 
     @register(Model)  # noqa
@@ -224,20 +190,16 @@ def mixin_one_model_by_subclass_and_with():
 
     @register(Model)  # noqa
     class Test:
-
         other = String()
 
 
 def mixin_one_model_with_subclass_and_subclass_mixin():
-
     @register(Mixin)
     class MixinName:
-
         name = String()
 
     @register(Model)
     class Test:
-
         id = Integer(primary_key=True)
 
     @register(Model)  # noqa
@@ -246,74 +208,60 @@ def mixin_one_model_with_subclass_and_subclass_mixin():
 
     @register(Mixin)  # noqa
     class MixinName:
-
         other = String()
 
 
 def inherit_by_another_model():
-
     @register(Model)
     class MainModel:
-
         id = Integer(primary_key=True)
         name = String()
 
     @register(Model)
     class Test(Model.MainModel):
-
         id = Integer(primary_key=True)
-        mainmodel = Integer(foreign_key=Model.MainModel.use('id'))
+        mainmodel = Integer(foreign_key=Model.MainModel.use("id"))
         other = String()
 
 
 def inherit_by_two_another_model():
-
     @register(Model)
     class MainModel:
-
         id = Integer(primary_key=True)
         name = String()
 
     @register(Model)
     class Test(Model.MainModel):
-
         id = Integer(primary_key=True)
-        mainmodel = Integer(foreign_key=Model.MainModel.use('id'))
+        mainmodel = Integer(foreign_key=Model.MainModel.use("id"))
         other = String()
 
     @register(Model)
     class Test2(Model.MainModel):
-
         id = Integer(primary_key=True)
-        mainmodel = Integer(foreign_key=Model.MainModel.use('id'))
+        mainmodel = Integer(foreign_key=Model.MainModel.use("id"))
         other = String()
 
 
 def inherit_by_another_model_and_subclass_mainmodel():
-
     @register(Model)
     class MainModel:
-
         id = Integer(primary_key=True)
         name = String()
 
     @register(Model)
     class Test(Model.MainModel):
-
         id = Integer(primary_key=True)
-        mainmodel = Integer(foreign_key=Model.MainModel.use('id'))
+        mainmodel = Integer(foreign_key=Model.MainModel.use("id"))
 
     @register(Model)  # noqa
     class MainModel:
-
         other = String()
 
 
 def inherit_base_and_add_method():
-
     @register(Core)
     class Base:
-
         def method_from_base(self, x):
             return x * 2
 
@@ -323,44 +271,36 @@ def inherit_base_and_add_method():
 
 
 def inherit_base_and_add_method_after_create_model():
-
     @register(Model)
     class Test:
         pass
 
     @register(Core)
     class Base:
-
         def method_from_base(self, x):
             return x * 2
 
 
 def inherit_base_and_add_method_sub_classes():
-
     @register(Core)
     class Base:
-
         def method_from_base(self, x):
             return x * 2
 
     @register(Model)
     class Test:
-
         def method_from_base(self, x):
             return super(Test, self).method_from_base(x) + 3
 
 
 def inherit_base_and_add_method_sub_classes_by_mixin():
-
     @register(Core)
     class Base:
-
         def method_from_base(self, x):
             return x * 2
 
     @register(Mixin)
     class TestMixin:
-
         def method_from_base(self, x):
             return super(TestMixin, self).method_from_base(x) + 3
 
@@ -370,16 +310,13 @@ def inherit_base_and_add_method_sub_classes_by_mixin():
 
 
 def inherit_sql_base_on_simple_model():
-
     @register(Core)
     class Base:
-
         def is_sql_base(self):
             return False
 
     @register(Core)
     class SqlBase:
-
         def is_sql_base(self):
             return True
 
@@ -389,32 +326,26 @@ def inherit_sql_base_on_simple_model():
 
 
 def inherit_sql_base_on_sql_model():
-
     @register(Core)
     class Base:
-
         def is_sql_base(self):
             return False
 
     @register(Core)
     class SqlBase:
-
         def is_sql_base(self):
             return True
 
     @register(Model)
     class Test:
-
         id = Integer(primary_key=True)
 
 
 class TestInherit:
-
     @pytest.fixture(autouse=True)
     def close_registry(self, request, bloks_loaded):
-
         def close():
-            if hasattr(self, 'registry'):
+            if hasattr(self, "registry"):
                 self.registry.close()
 
         request.addfinalizer(close)
@@ -434,20 +365,16 @@ class TestInherit:
 
     def test_inherit_multi_mixins(self):
         def add_in_registry():
-
             @register(Mixin)
             class MixinName:
-
                 name = String()
 
             @register(Mixin)
             class MixinOther:
-
                 other = String()
 
             @register(Model)
             class Test(Mixin.MixinName, Mixin.MixinOther):
-
                 id = Integer(primary_key=True)
 
         registry = self.init_registry(add_in_registry)
@@ -455,15 +382,12 @@ class TestInherit:
 
     def test_inherit_cascade_mixins(self):
         def add_in_registry():
-
             @register(Mixin)
             class MixinName:
-
                 name = String()
 
             @register(Mixin)
             class MixinOther:
-
                 other = String()
 
             @register(Mixin)
@@ -472,7 +396,6 @@ class TestInherit:
 
             @register(Model)
             class Test(Mixin.MTest):
-
                 id = Integer(primary_key=True)
 
         registry = self.init_registry(add_in_registry)
@@ -498,9 +421,10 @@ class TestInherit:
 
     def test_simple_subclass_model_change_type_and_subclass_add_field(self):
         registry = self.init_registry(
-            simple_subclass_model_change_type_and_subclass_add_field)
+            simple_subclass_model_change_type_and_subclass_add_field
+        )
 
-        t = registry.Test.insert(name=1, other='other')
+        t = registry.Test.insert(name=1, other="other")
         t2 = registry.Test.query().first()
         assert t2 is t
         assert t.name == 1
@@ -525,7 +449,7 @@ class TestInherit:
     def test_mixin_with_foreign_key_one_model(self):
         registry = self.init_registry(mixin_with_foreign_key_one_model)
 
-        val = 'test'
+        val = "test"
         registry.TestFk.insert(name=val)
         t = registry.Test.insert(name=val)
         t2 = registry.Test.query().first()
@@ -534,14 +458,14 @@ class TestInherit:
     def test_mixin_with_foreign_key_two_model(self):
         registry = self.init_registry(mixin_with_foreign_key_two_model)
 
-        for val in ('test', 'test2'):
+        for val in ("test", "test2"):
             registry.TestFk.insert(name=val)
 
-        t = registry.Test.insert(name='test')
+        t = registry.Test.insert(name="test")
         t2 = registry.Test.query().first()
         assert t2 is t
 
-        t3 = registry.Test2.insert(name='test2')
+        t3 = registry.Test2.insert(name="test2")
         t4 = registry.Test2.query().first()
         assert t3 is t4
 
@@ -551,7 +475,8 @@ class TestInherit:
 
     def test_mixin_one_model_with_subclass_and_subclass_mixin(self):
         registry = self.init_registry(
-            mixin_one_model_with_subclass_and_subclass_mixin)
+            mixin_one_model_with_subclass_and_subclass_mixin
+        )
         self.check_registry(registry.Test)
 
     def test_inherit_by_another_model(self):
@@ -565,7 +490,8 @@ class TestInherit:
 
     def test_inherit_by_another_model_and_subclass_mainmodel(self):
         registry = self.init_registry(
-            inherit_by_another_model_and_subclass_mainmodel)
+            inherit_by_another_model_and_subclass_mainmodel
+        )
         self.check_registry(registry.Test)
 
     def check_inherit_base(self, function, value):
@@ -577,15 +503,17 @@ class TestInherit:
         self.check_inherit_base(inherit_base_and_add_method, 4)
 
     def test_inherit_base_and_add_method_after_create_model(self):
-        self.check_inherit_base(inherit_base_and_add_method_after_create_model,
-                                4)
+        self.check_inherit_base(
+            inherit_base_and_add_method_after_create_model, 4
+        )
 
     def test_inherit_base_and_add_method_sub_classes(self):
         self.check_inherit_base(inherit_base_and_add_method_sub_classes, 7)
 
     def test_inherit_base_and_add_method_sub_classes_by_mixin(self):
         self.check_inherit_base(
-            inherit_base_and_add_method_sub_classes_by_mixin, 7)
+            inherit_base_and_add_method_sub_classes_by_mixin, 7
+        )
 
     def check_inherit_sql_base(self, function, value):
         registry = self.init_registry(function)
@@ -599,9 +527,7 @@ class TestInherit:
         self.check_inherit_sql_base(inherit_sql_base_on_sql_model, True)
 
     def test_inherit_model_with_relation_ship_auto_generate_column(self):
-
         def add_in_registry():
-
             @register(Model)
             class Test:
                 id = Integer(primary_key=True)
@@ -609,12 +535,12 @@ class TestInherit:
             @register(Model)
             class Test2:
                 id = Integer(primary_key=True)
-                test = Many2One(model=Model.Test, one2many='test2')
+                test = Many2One(model=Model.Test, one2many="test2")
 
             @register(Model)
             class Test3(Model.Test2):
                 id = Integer(primary_key=True)
-                test2 = Integer(foreign_key=Model.Test2.use('id'))
+                test2 = Integer(foreign_key=Model.Test2.use("id"))
 
         registry = self.init_registry(add_in_registry)
         t = registry.Test.insert()
@@ -624,9 +550,7 @@ class TestInherit:
         assert t2.test is t
 
     def test_inherit_model_with_relation_ship(self):
-
         def add_in_registry():
-
             @register(Model)
             class Test:
                 id = Integer(primary_key=True)
@@ -634,13 +558,13 @@ class TestInherit:
             @register(Model)
             class Test2:
                 id = Integer(primary_key=True)
-                test_id = Integer(foreign_key=Model.Test.use('id'))
-                test = Many2One(model=Model.Test, one2many='test2')
+                test_id = Integer(foreign_key=Model.Test.use("id"))
+                test = Many2One(model=Model.Test, one2many="test2")
 
             @register(Model)
             class Test3(Model.Test2):
                 id = Integer(primary_key=True)
-                test2 = Integer(foreign_key=Model.Test2.use('id'))
+                test2 = Integer(foreign_key=Model.Test2.use("id"))
 
         registry = self.init_registry(add_in_registry)
         t = registry.Test.insert()
